@@ -5,10 +5,11 @@ class Host(object):
     for Chef deployment, role addition, etc.
     """
 
-    def __init__(self, name=None, host_string=None, password=None):
+    def __init__(self, name=None, host_string=None, password=None, environment=None):
         self.name = name
         self.host_string = host_string
         self.password = password
+        self.environment = environment
 
     def __repr__(self):
         return '<Host name={0}, host_string={1}, password={2}>'.format(
@@ -18,4 +19,5 @@ class Host(object):
     def __eq__(self, other):
         return (self.name == other.name and
                 self.host_string == other.host_string and
-                self.password == other.password)
\ No newline at end of file
+                self.password == other.password,
+                self.environment == other.environment)
\ No newline at end of file
